RButtonSpinnerContext class final

Context for the button spinner slot.

Annotations

Constructors

RButtonSpinnerContext({required RButtonSpec spec, required RButtonState state, required Widget child})
const

Properties

child Widget
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec RButtonSpec
final
state RButtonState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited