RCheckboxListTileState class final

Checkbox list tile interaction state.

Annotations

Constructors

RCheckboxListTileState({bool isPressed = false, bool isHovered = false, bool isFocused = false, bool isDisabled = false, bool isSelected = false, bool isError = false})
const
RCheckboxListTileState.fromWidgetStates(Set<WidgetState> states)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisabled bool
final
isError bool
final
isFocused bool
final
isHovered bool
final
isPressed bool
final
isSelected bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWidgetStates() Set<WidgetState>

Operators

operator ==(Object other) bool
The equality operator.
inherited