RCheckboxSemantics class final

Semantic information for checkbox accessibility.

Annotations

Constructors

RCheckboxSemantics({String? label, required bool isEnabled, required bool? value, required bool isTristate})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isChecked bool
no setter
isEnabled bool
Whether the checkbox is currently enabled.
final
isIndeterminate bool
no setter
isTristate bool
Whether the checkbox supports the indeterminate state.
final
label String?
Accessibility label for screen readers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value bool?
The current checkbox value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override