RCheckboxSlots class final
Checkbox slots for partial customization (Replace/Decorate/Enhance).
- Annotations
Constructors
-
RCheckboxSlots({SlotOverride<
RCheckboxBoxContext> ? box, SlotOverride<RCheckboxMarkContext> ? mark, SlotOverride<RCheckboxPressOverlayContext> ? pressOverlay}) -
const
Properties
-
box
→ SlotOverride<
RCheckboxBoxContext> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mark
→ SlotOverride<
RCheckboxMarkContext> ? -
final
-
pressOverlay
→ SlotOverride<
RCheckboxPressOverlayContext> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited