RSwitchSlots class final
Switch slots for partial customization (Replace/Decorate/Enhance).
- Annotations
Constructors
-
RSwitchSlots({SlotOverride<
RSwitchTrackContext> ? track, SlotOverride<RSwitchThumbContext> ? thumb, SlotOverride<RSwitchPressOverlayContext> ? pressOverlay}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pressOverlay
→ SlotOverride<
RSwitchPressOverlayContext> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
thumb
→ SlotOverride<
RSwitchThumbContext> ? -
final
-
track
→ SlotOverride<
RSwitchTrackContext> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited