RButtonSlots class final
Button slots for partial customization (Replace/Decorate/Enhance).
- Annotations
Constructors
-
RButtonSlots({SlotOverride<
RButtonSurfaceContext> ? surface, SlotOverride<RButtonContentContext> ? content, SlotOverride<RButtonIconContext> ? leadingIcon, SlotOverride<RButtonIconContext> ? trailingIcon, SlotOverride<RButtonSpinnerContext> ? spinner}) -
const
Properties
-
content
→ SlotOverride<
RButtonContentContext> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
leadingIcon
→ SlotOverride<
RButtonIconContext> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spinner
→ SlotOverride<
RButtonSpinnerContext> ? -
final
-
surface
→ SlotOverride<
RButtonSurfaceContext> ? -
final
-
trailingIcon
→ SlotOverride<
RButtonIconContext> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited