RButtonSpec class final
Button specification (static, from widget props).
Contains visual variant, sizing, and semantic information. This is the "what" of the button (not the "how" — that's the renderer).
- Annotations
Constructors
- RButtonSpec({RButtonVariant variant = RButtonVariant.outlined, RButtonSize size = RButtonSize.medium, String? semanticLabel})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
Accessibility label (for screen readers).
final
- size → RButtonSize
-
Size variant.
final
- variant → RButtonVariant
-
Visual appearance variant.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited