RSwitchListTileSpec class final
Switch list tile specification (static, from widget props).
- Annotations
Constructors
- RSwitchListTileSpec({required bool value, String? semanticLabel, bool selected = false, Color? selectedColor, EdgeInsetsGeometry? contentPadding, RSwitchControlAffinity controlAffinity = RSwitchControlAffinity.platform, bool isThreeLine = false, bool dense = false, bool hasSubtitle = false})
-
const
Properties
- contentPadding → EdgeInsetsGeometry?
-
final
- controlAffinity → RSwitchControlAffinity
-
final
- dense → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSubtitle → bool
-
final
- isThreeLine → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
final
- selectedColor → Color?
-
final
- semanticLabel → String?
-
final
- value → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited