RSwitchMotionTokens class final
Motion tokens for switch visual transitions.
The goal is to avoid hardcoding durations inside preset renderers.
- Annotations
Constructors
- RSwitchMotionTokens({required Duration stateChangeDuration, Duration? thumbSlideDuration, Duration? thumbToggleDuration})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateChangeDuration → Duration
-
Duration for visual state transitions (focus/hover/pressed/checked).
final
- thumbSlideDuration → Duration?
-
Duration for thumb sliding animation.
If null, defaults to stateChangeDuration.
final
- thumbToggleDuration → Duration?
-
Duration for thumb toggle animation (TweenSequence).
Material 3: 300ms
If null, defaults to stateChangeDuration.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override